@@ -190,7 +190,7 @@ function(what_sgp_object=NULL,
 
 		### Print finish and return SGP object
 
-		messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
+		messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetakenSGP(started.at)), "\n"))
 		return(sgp_object)
 	} ### END is.null(with_sgp_data_LONG)
 
@@ -272,7 +272,7 @@ function(what_sgp_object=NULL,
 
 			### Print finish and return SGP object
 
-			messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
+			messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetakenSGP(started.at)), "\n"))
 			return(what_sgp_object)
 
 		} else { ### END if (overwrite.existing.data)
@@ -414,7 +414,7 @@ function(what_sgp_object=NULL,
 
 				### Print finish and return SGP object
 
-				messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
+				messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetakenSGP(started.at)), "\n"))
 				return(what_sgp_object)
 			} else {
 				if (update.old.data.with.new) {
@@ -487,7 +487,7 @@ function(what_sgp_object=NULL,
 
 				### Print finish and return SGP object
 
-				messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
+				messageSGP(paste("Finished updateSGP", prettyDate(), "in", convertTime(timetakenSGP(started.at)), "\n"))
 				return(what_sgp_object)
 			} ### END if else (!is.null(sgp.use.my.coefficient.matrices))
 		} ### END if (overwrite.existing.data)
